##
##  libsoup.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2019 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_major 2.59
%define       V_minor 90.1

#   package information
Name:         libsoup
Summary:      HTTP Client/Server Library
URL:          http://live.gnome.org/LibSoup
Vendor:       A. Graveley, D. Porter, M. De Icaza, J. Shaw, D. Winship
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      LGPL
Version:      %{V_major}.%{V_minor}
Release:      20190119

#   list of sources
Source0:      http://ftp.gnome.org/pub/GNOME/sources/libsoup/%{V_major}/libsoup-%{version}.tar.xz
Patch0:       libsoup.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, pkgconfig
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  glib, libxml
PreReq:       glib, libxml
BuildPreReq:  openssl
PreReq:       openssl

%description
    Libsoup is an HTTP client/server library. It uses GObjects and the
    glib main loop and integrates well with GNOME and GTK+ applications.
    Since it is based only on glib, it can also be used in command
    line and daemon-based applications. It features both asynchronous
    (GMainLoop and callback-based) and synchronous APIs, automatically
    cached connections, SSL support using GnuTLS, and proxy support
    including authentication and SSL tunneling. Client support includes
    Digest, NTLM, and basic authentication, and server support includes
    Digest and Basic authentication.

%track
    prog libsoup = {
        version   = %{version}
        url       = http://ftp.gnome.org/pub/GNOME/sources/libsoup/%{V_major}/
        regex     = libsoup-(__VER__)\.tar\.xz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --without-gssapi \
        --without-gnome \
        --disable-vala \
        --disable-gtk-doc \
        --disable-tls-check \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/locale >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/gtk-doc >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

